##  Datapoints for Rationalization
The key data points are:
  * Functional fit
  * Technical fit
  * Business criticality
  * Application cost: Total cost of ownership (TCO) of applications including license, maintenance and support costs
  * Infrastructure cost: Total annual cost on the relation between an application and IT components


For more details on the cost types, refer to [Cost Management](https://help.sap.com/docs/leanix/ea/cost-management?locale=en-US&state=PRODUCTION&version=CLOUD "Track and analyze IT costs across projects, applications, and infrastructure. Support strategic financial decisions in enterprise architecture with the right insights from reports.").
